from setuptools import setup

setup(
    name='pyugpu-info',    # This is the name of your PyPI-package.
    version='0.2',                          # Update the version number for new releases
    scripts=['pyugpu-info']                  # The name of your scipt, and also the command you'll be using for calling it
)
